==> haskell-dns-2.0.10-39-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-dns.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dns
version: 2.0.10
id: dns-2.0.10-8Ogmoqe6tYj86SN7leMRD8
key: dns-2.0.10-8Ogmoqe6tYj86SN7leMRD8
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.
category: Network
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.DNS Network.DNS.Lookup Network.DNS.Resolver
    Network.DNS.Utils Network.DNS.Types Network.DNS.Encode
    Network.DNS.Decode
hidden-modules: Network.DNS.Internal Network.DNS.StateBinary
abi: 0dde9cc97761ec9e7c5740f4b242ee3e
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/dns-2.0.10
library-dirs: /usr/lib/ghc-8.0.2/site-local/dns-2.0.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/dns-2.0.10
hs-libraries: HSdns-2.0.10-8Ogmoqe6tYj86SN7leMRD8
depends:
    attoparsec-0.13.1.0-7xLJO1EwFQpJLBzOR8WqkC base-4.9.1.0
    binary-0.8.3.0 bytestring-0.10.8.1
    conduit-1.2.11-GzxQexWP3ouJXox0rAqJ5D
    conduit-extra-1.1.16-5YILVd78SGn9wwYaAO3g7W containers-0.5.7.1
    iproute-1.7.1-EJjAtfniBUorobFQnk7lR
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    network-2.6.3.2-IsLM4TXcLoRI0fmmBYVyQz
    random-1.1-9tceXaeYIMZ4JrKq20Egog
    resourcet-1.1.9-DJf1ANdxSraDnKUpiOoSOA
    safe-0.3.15-2Yd45VWFfdcKqKyispOifY
haddock-interfaces: /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html: /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dns-2.0.12-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-dns.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dns
version: 2.0.12
id: dns-2.0.12-iiT0vSZMzQJ4AaTlQk4Gz
key: dns-2.0.12-iiT0vSZMzQJ4AaTlQk4Gz
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.
category: Network
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.DNS Network.DNS.Lookup Network.DNS.Resolver
    Network.DNS.Utils Network.DNS.Types Network.DNS.Encode
    Network.DNS.Decode
hidden-modules: Network.DNS.Internal Network.DNS.StateBinary
abi: 8139401569a295a6fe3258b670126609
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/dns-2.0.12
library-dirs: /usr/lib/ghc-8.0.2/site-local/dns-2.0.12
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/dns-2.0.12
hs-libraries: HSdns-2.0.12-iiT0vSZMzQJ4AaTlQk4Gz
depends:
    attoparsec-0.13.2.0-JkqjYPxw7sG9Iq2J4E1Ndn base-4.9.1.0
    binary-0.8.3.0 bytestring-0.10.8.1
    conduit-1.2.11-IZZgx95zXN83i3dNdoRZvV
    conduit-extra-1.1.16-CDLMlreEXPI9wDo2xYmnfQ containers-0.5.7.1
    iproute-1.7.1-EJjAtfniBUorobFQnk7lR
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    network-2.6.3.2-IsLM4TXcLoRI0fmmBYVyQz
    random-1.1-9tceXaeYIMZ4JrKq20Egog
    resourcet-1.1.9-AaZCIqnYF9zJKlT6eUxN1Z
    safe-0.3.15-2Yd45VWFfdcKqKyispOifY
haddock-interfaces: /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html: /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
